import { Component, Input } from "@angular/core";
import { NgbActiveModal } from "@ng-bootstrap/ng-bootstrap";
import { TableexcelService } from "src/app/_services/tableexcel.service";
import { LoginService } from "../../service/login.service";
import { BuildingService } from "../../service/monitoring-api.service";

@Component({
  selector: "app-modal-export",
  templateUrl: "./modal-export.component.html",
  styleUrls: ["./modal-export.component.css"],
})
export class ModalExportComponent {
  @Input() buildingId: any = 0;
  @Input() dataIndex: any = 0;
  @Input() floorId: any = 0;
  @Input() roomId: any = 0;
  @Input() mode: any = "";

  buildingOnly = false;
  floorOnly = false;
  roomOnly = false;

  data: any;
  filteredRows: any[];
  data_device: any[];
  kwhTerm: string = "";
  costTerm: string = "";
  data_cost: any;
  dataExport: any;
  formattedEndDate: any;
  spinnerExportActive = false;
  constructor(
    public activeModal: NgbActiveModal,
    private tableexcelService: TableexcelService,
    private authService: LoginService,
    private monitoringService: BuildingService
  ) {}

  ngOnInit() {
    this.authService.startTokenCheck();
    this.authService.startTrackingActivity();
    this.fetchData();
  }

  ngAfterViewInit(): void {
    if (this.buildingId !== 0 && this.floorId === 0 && this.roomId === 0) {
      this.buildingOnly = true;
      this.floorOnly = false;
      this.roomOnly = false;
    } else if (
      this.buildingId !== 0 &&
      this.floorId !== 0 &&
      this.roomId === 0
    ) {
      this.buildingOnly = false;
      this.floorOnly = true;
      this.roomOnly = false;
    } else if (
      this.buildingId !== 0 &&
      this.floorId !== 0 &&
      this.roomId !== 0
    ) {
      this.buildingOnly = false;
      this.floorOnly = false;
      this.roomOnly = true;
    }
  }

  fetchData() {
    this.monitoringService
      .getDetailChart(
        this.dataIndex + 1,
        this.buildingId,
        this.floorId,
        this.roomId
      )
      .subscribe((response) => {
        this.dataExport = response.data;
        this.data_cost = response.data.map((item) => ({
          BuildingName: item.building_name,
          floorName: item.floor_name,
          roomName: item.room_name,
          deviceName: item.device_name,
          duration: item.duration,
          priceKwh: item.price_kwh,
          estimationCost: item.estimation_cost,
          // periode: this.convertToUTC7(item.periode)
        }));
        console.log(this.data_cost);
      });
  }

  convertToUTC7(dateString: string): string {
    const date = new Date(dateString);
    const utc7Offset = 7 * 60; // UTC+7 in minutes
    const localOffset = date.getTimezoneOffset();
    const totalOffset = utc7Offset - localOffset;
    const utc7Date = new Date(date.getTime() + totalOffset * 60 * 1000);
    return utc7Date.toISOString();
  }

  export() {
    this.spinnerExportActive = true;
    setTimeout(() => {
      let columnsToExport = [];
      let exportText = "";
      if (this.mode === "building") {
        columnsToExport = [
          "floorName",
          "roomName",
          "deviceName",
          "duration",
          "priceKwh",
          "estimationCost",
        ];
        exportText = "export_detail_monitoring_building";
      } else if (this.mode === "floor") {
        columnsToExport = [
          "roomName",
          "deviceName",
          "duration",
          "priceKwh",
          "estimationCost",
        ];
        exportText = "export_detail_monitoring_floor";
      } else if (this.mode === "room") {
        columnsToExport = [
          "deviceName",
          "duration",
          "priceKwh",
          "estimationCost",
        ];
        exportText = "export_detail_monitoring_room";
      }

      this.tableexcelService.exportAsExcelFileMonitoringDetail(
        this.data_cost,
        exportText,
        columnsToExport,
        this.mode
      );
      this.spinnerExportActive = false;
      this.activeModal.close("Export completed");
    }, 3000);
  }
}
